@@ -40,19 +40,14 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
     def setUp(self):
         super(TestProcessDriversAndHardwareTypes, self).setUp()
         self.conf = mock.Mock(**{key: getattr(undercloud_config.CONF, key)
-                                 for key in (
-                                     'enabled_hardware_types',
-                                     'enable_node_discovery',
-                                     'discovery_default_driver',
-                                     'ironic_enabled_network_interfaces',
-                                     'ironic_default_network_interface')})
+                                 for key in ('enabled_hardware_types',
+                                             'enable_node_discovery',
+                                             'discovery_default_driver')})
 
     def test_defaults(self):
         env = {}
         undercloud_config._process_drivers_and_hardware_types(self.conf, env)
         self.assertEqual({
-            'IronicEnabledNetworkInterfaces': ['flat'],
-            'IronicDefaultNetworkInterface': 'flat',
             'IronicEnabledHardwareTypes': ['idrac', 'ilo', 'ipmi', 'redfish'],
             'IronicEnabledBootInterfaces': ['ilo-pxe', 'ipxe', 'pxe'],
             'IronicEnabledBiosInterfaces': ['ilo', 'no-bios', 'redfish'],
@@ -75,8 +70,6 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
 
         undercloud_config._process_drivers_and_hardware_types(self.conf, env)
         self.assertEqual({
-            'IronicEnabledNetworkInterfaces': ['flat'],
-            'IronicDefaultNetworkInterface': 'flat',
             # ipmi added because it's the default discovery driver
             'IronicEnabledHardwareTypes': ['ipmi', 'redfish'],
             'IronicEnabledBootInterfaces': ['ipxe', 'pxe'],
@@ -103,8 +96,6 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
 
         undercloud_config._process_drivers_and_hardware_types(self.conf, env)
         self.assertEqual({
-            'IronicEnabledNetworkInterfaces': ['flat'],
-            'IronicDefaultNetworkInterface': 'flat',
             'IronicEnabledHardwareTypes': ['fake-hardware', 'idrac', 'ilo',
                                            'ipmi', 'irmc', 'redfish', 'snmp',
                                            'staging-ovirt', 'xclarity'],
@@ -130,9 +121,9 @@ class TestProcessDriversAndHardwareTypes(base.TestCase):
         }, env)
 
 
-class TestBaseNetworkSettings(base.TestCase):
+class TestNetworkSettings(base.TestCase):
     def setUp(self):
-        super(TestBaseNetworkSettings, self).setUp()
+        super(TestNetworkSettings, self).setUp()
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         # don't actually load config from ~/undercloud.conf
         self.mock_config_load = self.useFixture(
@@ -169,8 +160,6 @@ class TestBaseNetworkSettings(base.TestCase):
                          dns_nameservers=[],
                          group='ctlplane-subnet')
 
-
-class TestNetworkSettings(TestBaseNetworkSettings):
     def test_default(self):
         env = {}
         undercloud_config._process_network_args(env)
@@ -196,7 +185,7 @@ class TestNetworkSettings(TestBaseNetworkSettings):
         }
         self.assertEqual(expected, env)
 
-    def test_ipv6_control_plane_stateless_default(self):
+    def test_ipv6_control_plane(self):
         env = {}
         self.conf.config(local_ip='fd12:3456:789a:1::2/64',
                          undercloud_admin_host='fd12:3456:789a:1::3',
@@ -214,55 +203,6 @@ class TestNetworkSettings(TestBaseNetworkSettings):
                          host_routes=[],
                          group='ctlplane-subnet')
         undercloud_config._process_network_args(env)
-        expected = {
-            'NovaIPv6': True,
-            'RabbitIPv6': True,
-            'MemcachedIPv6': True,
-            'RedisIPv6': True,
-            'MysqlIPv6': True,
-            'IronicIpVersion': '6',
-            'ControlPlaneStaticRoutes': [],
-            'IronicInspectorSubnets': [
-                {'gateway': 'fd12:3456:789a:1::1',
-                 'host_routes': [],
-                 'ip_range': 'fd12:3456:789a:1::,static',
-                 'netmask': 'ffff:ffff:ffff:ffff::',
-                 'tag': 'ctlplane-subnet',
-                 'mtu': 1500}],
-            'MasqueradeNetworks': {},
-            'UndercloudCtlplaneSubnets': {
-                'ctlplane-subnet': {
-                    'AllocationPools': [
-                        {'start': 'fd12:3456:789a:1::10',
-                         'end': 'fd12:3456:789a:1::20'}],
-                    'DnsNameServers': ['fd12:3456:789a:1::5',
-                                       'fd12:3456:789a:1::6'],
-                    'HostRoutes': [],
-                    'NetworkCidr': 'fd12:3456:789a:1::/64',
-                    'NetworkGateway': 'fd12:3456:789a:1::1'}},
-            'UndercloudCtlplaneIPv6AddressMode': 'dhcpv6-stateless',
-        }
-        self.assertEqual(expected, env)
-
-    def test_ipv6_control_plane_stateful(self):
-        env = {}
-        self.conf.config(local_ip='fd12:3456:789a:1::2/64',
-                         undercloud_admin_host='fd12:3456:789a:1::3',
-                         undercloud_public_host='fd12:3456:789a:1::4',
-                         ipv6_address_mode='dhcpv6-stateful')
-        self.conf.config(cidr='fd12:3456:789a:1::/64',
-                         dhcp_start='fd12:3456:789a:1::10',
-                         dhcp_end='fd12:3456:789a:1::20',
-                         dhcp_exclude=[],
-                         dns_nameservers=['fd12:3456:789a:1::5',
-                                          'fd12:3456:789a:1::6'],
-                         inspection_iprange=('fd12:3456:789a:1::30,'
-                                             'fd12:3456:789a:1::40'),
-                         gateway='fd12:3456:789a:1::1',
-                         masquerade=False,
-                         host_routes=[],
-                         group='ctlplane-subnet')
-        undercloud_config._process_network_args(env)
         expected = {
             'NovaIPv6': True,
             'RabbitIPv6': True,
@@ -289,7 +229,7 @@ class TestNetworkSettings(TestBaseNetworkSettings):
                     'HostRoutes': [],
                     'NetworkCidr': 'fd12:3456:789a:1::/64',
                     'NetworkGateway': 'fd12:3456:789a:1::1'}},
-            'UndercloudCtlplaneIPv6AddressMode': 'dhcpv6-stateful',
+            'UndercloudCtlplaneIPv6AddressMode': 'dhcpv6-stateless',
         }
         self.assertEqual(expected, env)
 
@@ -319,14 +259,18 @@ class TestNetworkSettings(TestBaseNetworkSettings):
                          undercloud_admin_host='192.168.24.3',
                          undercloud_public_host='192.168.24.1',
                          generate_service_certificate=True)
-        undercloud_config._process_network_args(env)
+        self.assertRaises(exceptions.InvalidConfiguration,
+                          undercloud_config._process_network_args,
+                          env)
 
         # undercloud_admin_host == undercloud_public_host
         self.conf.config(local_ip='192.168.24.1/24',
                          undercloud_admin_host='192.168.24.2',
                          undercloud_public_host='192.168.24.2',
                          generate_service_certificate=True)
-        undercloud_config._process_network_args(env)
+        self.assertRaises(exceptions.InvalidConfiguration,
+                          undercloud_config._process_network_args,
+                          env)
 
         # We do not care about ip duplication when ssl is disabled
         self.conf.config(local_ip='192.168.24.1/24',
@@ -881,36 +825,6 @@ class TestNetworkSettings(TestBaseNetworkSettings):
         }
         self.assertEqual(expected, env)
 
-    def test_generate_inspection_subnets(self):
-        result = undercloud_config._generate_inspection_subnets()
-        expected = [{'gateway': '192.168.24.1',
-                     'host_routes': [],
-                     'ip_range': '192.168.24.100,192.168.24.120',
-                     'mtu': 1500,
-                     'netmask': '255.255.255.0',
-                     'tag': 'ctlplane-subnet'}]
-        self.assertEqual(expected, result)
-
-    def test_generate_inspection_subnets_invalid(self):
-        self.conf.config(subnets=['ctlplane-subnet', 'subnet1'])
-        self.conf.config(host_routes=[{'destination': '10.10.10.254/32',
-                                       'nexthop': '192.168.24.1'}],
-                         group='ctlplane-subnet')
-        self.conf.register_opts(self.opts, group=self.grp1)
-        self.conf.config(group='subnet1')
-        self.assertRaises(exceptions.DeploymentError,
-                          undercloud_config._generate_inspection_subnets)
-
-
-class TestChronySettings(TestBaseNetworkSettings):
-    def test_default(self):
-        env = {}
-        undercloud_config._process_chrony_acls(env)
-        expected = {
-            'ChronyAclRules': ['allow 192.168.24.0/24'],
-        }
-        self.assertEqual(expected, env)
-
 
 class TestTLSSettings(base.TestCase):
     def test_public_host_with_ip_should_give_ip_endpoint_environment(self):
