@@ -15,13 +15,11 @@
 from __future__ import print_function
 
 import argparse
-from collections import OrderedDict
 import json
 import logging
 import os
 import os.path
 from prettytable import PrettyTable
-from pwd import getpwuid
 import re
 import shutil
 import six
@@ -36,6 +34,14 @@ from osc_lib.i18n import _
 from swiftclient.exceptions import ClientException
 from tripleo_common import update
 
+# FIXME(chkumar246): Once https://review.opendev.org/664568 gets merged
+# and new version of tripleo-common gots released, It requires a version
+# bump in requirements.txt.
+try:
+    from tripleo_common.utils import clouds_yaml
+except ImportError:
+    from tripleoclient.v1 import mock_clouds_yaml as clouds_yaml
+
 from tripleoclient import command
 from tripleoclient import constants
 from tripleoclient import exceptions
@@ -75,7 +81,7 @@ class DeployOvercloud(command.Command):
         # *Identifier will be update to timestamp value during the deploy
         # workflow, but till then for all heat stack validations, we need
         # and entry for starting the deploy action.
-        if stack_is_new or args.skip_deploy_identifier:
+        if stack_is_new:
             parameters['DeployIdentifier'] = ''
         else:
             parameters[
@@ -105,33 +111,6 @@ class DeployOvercloud(command.Command):
                 ('NovaComputeLibvirtType', 'libvirt_type'),
             )
             param_args = param_args + new_stack_args
-        else:
-            globalcfg = utils.get_stack_output_item(stack, 'GlobalConfig')
-
-            # verif if tls was enabled in previous deploy run
-            if globalcfg and 'use_tls_for_nbd' in globalcfg:
-                nbd_tls = globalcfg['use_tls_for_nbd']
-                self.log.debug("use_tls_for_nbd=%s" % nbd_tls)
-                parameters['UseTLSTransportForNbd'] = nbd_tls
-            else:
-                # in case of an update use_tls_for_nbd global config key
-                # won't exist, check the nbd_tls hiera key from the roledata.
-                roledata = utils.get_stack_output_item(stack, 'RoleData')
-                if roledata:
-                    nbd_tls_key = 'nova::compute::libvirt::qemu::nbd_tls'
-                    for key in roledata:
-                        if not roledata[key]:
-                            # Probably an incomplete stack, ignore it.
-                            continue
-                        config_settings = roledata[key].get('config_settings')
-                        if config_settings:
-                            nbd_tls = config_settings.get(nbd_tls_key)
-                            if nbd_tls:
-                                self.log.debug("use_tls_for_nbd=%s" % nbd_tls)
-                                parameters['UseTLSTransportForNbd'] = nbd_tls
-                                break
-                            else:
-                                parameters['UseTLSTransportForNbd'] = False
 
         # Update parameters from commandline
         for param, arg in param_args:
@@ -143,20 +122,6 @@ class DeployOvercloud(command.Command):
 
         return parameters
 
-    def _cleanup_host_entry(self, entry):
-        # remove any tab or space excess
-        entry_stripped = re.sub('[ \t]+', ' ', str(entry).rstrip())
-        # removes any duplicate identical lines
-        unique_lines = list(set(entry_stripped.splitlines()))
-        ret = ''
-        for line in unique_lines:
-            # remove any duplicate word
-            hosts_unique = (' '.join(
-                OrderedDict((w, w) for w in line.split()).keys()))
-            if hosts_unique != '':
-                ret += hosts_unique + '\n'
-        return ret.rstrip('\n')
-
     def _get_undercloud_host_entry(self):
         """Get hosts entry for undercloud ctlplane network
 
@@ -164,13 +129,13 @@ class DeployOvercloud(command.Command):
         """
         ctlplane_hostname = '.'.join([utils.get_short_hostname(), 'ctlplane'])
         cmd = ['getent', 'hosts', ctlplane_hostname]
-        process = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                   universal_newlines=True)
+        process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
         out, err = process.communicate()
         if process.returncode != 0:
             raise exceptions.DeploymentError('No entry for %s in /etc/hosts'
                                              % ctlplane_hostname)
-        return self._cleanup_host_entry(out)
+
+        return out.rstrip()
 
     def _create_breakpoint_cleanup_env(self, tht_root, container_name):
         bp_env = {}
@@ -191,12 +156,6 @@ class DeployOvercloud(command.Command):
             container_name)
         return parameter_defaults
 
-    def _check_limit_skiplist_warning(self, env):
-        if env.get('parameter_defaults').get('DeploymentServerBlacklist'):
-            msg = _('[WARNING] DeploymentServerBlacklist is defined and will '
-                    'be ignored because --limit has been specified.')
-            self.log.warning(msg)
-
     def _write_user_environment(self, env_map, abs_env_path, tht_root,
                                 container_name):
         # We write the env_map to the local /tmp tht_root and also
@@ -488,25 +447,9 @@ class DeployOvercloud(command.Command):
             cleanup=(not parsed_args.no_cleanup))
         template_utils.deep_update(env, localenv)
 
-        if parsed_args.limit:
-            # check if skip list is defined while using --limit and throw a
-            # warning if necessary
-            self._check_limit_skiplist_warning(env)
-
         if stack:
-            if not parsed_args.disable_validations:
-                # note(aschultz): network validation goes here before we deploy
-                utils.check_stack_network_matches_env_files(stack, env)
-                ceph_deployed = env.get('resource_registry', {}).get(
-                    'OS::TripleO::Services::CephMon', 'OS::Heat::None')
-                ceph_external = env.get('resource_registry', {}).get(
-                    'OS::TripleO::Services::CephExternal', 'OS::Heat::None')
-                # note (fpantano) if ceph is not TripleO deployed and no
-                # external ceph cluster are present, there's no reason to
-                # make this check and we can simply ignore it
-                if (ceph_deployed != "OS::Heat::None"
-                        or ceph_external != "OS::Heat::None"):
-                    utils.check_ceph_fsid_matches_env_files(stack, env)
+            # note(aschultz): network validation goes here before we deploy
+            utils.check_stack_network_matches_env_files(stack, env)
             bp_cleanup = self._create_breakpoint_cleanup_env(
                 tht_root, parsed_args.stack)
             template_utils.deep_update(env, bp_cleanup)
@@ -679,17 +622,14 @@ class DeployOvercloud(command.Command):
         with open(parsed_args.baremetal_deployment, 'r') as fp:
             roles = yaml.safe_load(fp)
 
-        key = self.get_key_pair(parsed_args)
-        with open('{}.pub'.format(key), 'rt') as fp:
+        with open(parsed_args.overcloud_ssh_key, 'rt') as fp:
             ssh_key = fp.read()
 
         parameter_defaults = baremetal.deploy_roles(
             self.app.client_manager,
             plan=parsed_args.stack,
-            roles=roles,
-            ssh_keys=[ssh_key],
-            ssh_user_name=parsed_args.overcloud_ssh_user
-        )
+            roles=roles, ssh_keys=[ssh_key],
+            ssh_user_name=parsed_args.overcloud_ssh_user)
 
         env_path, swift_path = self._write_user_environment(
             parameter_defaults,
@@ -712,42 +652,6 @@ class DeployOvercloud(command.Command):
             roles=roles
         )
 
-    def _post_stack_validation(self, stack):
-        """Post stack update mandatory validation
-
-           Runs a validation in the to make sure that KernelArgs either
-           contains a TSX parameter or the ForceNoTsx parameter is defined.
-           This is a mandatory validation and it has to happen before
-           as soon as possible.
-           """
-
-        libvirt_service = "OS::TripleO::Services::NovaLibvirt"
-        services = filter(lambda x: (x.endswith('Services') and
-                                     libvirt_service in stack.parameters[x]),
-                          stack.parameters)
-        impacted_roles = []
-        for i in services:
-            role_name = re.sub('Services$', '', i)
-            role_param = stack.parameters.get(role_name + 'Parameters')
-            if role_param:
-                role_params = json.loads(role_param)
-                kernel_args = role_params.get('KernelArgs')
-                no_tsx = role_params.get('ForceNoTsx')
-                if (not no_tsx and
-                   (not kernel_args or "tsx=" not in kernel_args)):
-                    impacted_roles.append(role_name)
-        if len(impacted_roles):
-            self.log.error("Roles in the following list are expected to have "
-                           "a TSX flag configured in their KernelArgs "
-                           "parameter. For more information on why we must "
-                           "explicitly define the TSX flag, please visit: "
-                           "https://access.redhat.com/solutions/6036141")
-            self.log.error("You can also skip this validation by setting "
-                           "ForceNoTsx parameter for the desired role(s)")
-            self.log.error("Impacted roles: {roles}".format(
-                roles=",".join(impacted_roles)))
-            raise exceptions.PostStackValidationError()
-
     def get_parser(self, prog_name):
         # add_help doesn't work properly, set it to False:
         parser = argparse.ArgumentParser(
@@ -784,27 +688,15 @@ class DeployOvercloud(command.Command):
         )
         parser.add_argument(
             '--overcloud-ssh-key',
-            default=None,
-            help=_('Key path for ssh access to overcloud nodes. When'
-                   'undefined the key will be autodetected.')
+            default=os.path.join(
+                os.path.expanduser('~'), '.ssh', 'id_rsa'),
+            help=_('Key path for ssh access to overcloud nodes.')
         )
         parser.add_argument(
             '--overcloud-ssh-network',
             help=_('Network name to use for ssh access to overcloud nodes.'),
             default='ctlplane'
         )
-        parser.add_argument(
-            '--overcloud-ssh-enable-timeout',
-            help=_('Timeout for the ssh enable process to finish.'),
-            type=int,
-            default=constants.ENABLE_SSH_ADMIN_TIMEOUT
-        )
-        parser.add_argument(
-            '--overcloud-ssh-port-timeout',
-            help=_('Timeout for to wait for the ssh port to become active.'),
-            type=int,
-            default=constants.ENABLE_SSH_ADMIN_SSH_PORT_TIMEOUT
-        )
         parser.add_argument(
             '--environment-file', '-e', metavar='<HEAT ENVIRONMENT FILE>',
             action='append', dest='environment_files',
@@ -1002,44 +894,10 @@ class DeployOvercloud(command.Command):
                             metavar='<baremetal_deployment.yaml>',
                             help=_('Configuration file describing the '
                                    'baremetal deployment'))
-        parser.add_argument(
-            '--limit',
-            action='store',
-            default=None,
-            help=_("A string that identifies a single node or comma-separated"
-                   "list of nodes the config-download Ansible playbook "
-                   "execution will be limited to. For example: --limit"
-                   " \"compute-0,compute-1,compute-5\".")
-        )
-        parser.add_argument(
-            '--tags',
-            action='store',
-            default=None,
-            help=_('A list of tags to use when running the config-download'
-                   ' ansible-playbook command.')
-        )
-        parser.add_argument(
-            '--skip-tags',
-            action='store',
-            default=None,
-            help=_('A list of tags to skip when running the'
-                   ' config-download ansible-playbook command.')
-        )
-        parser.add_argument(
-            '--ansible-forks',
-            action='store',
-            default=None,
-            type=int,
-            help=_('The number of Ansible forks to use for the'
-                   ' config-download ansible-playbook command.')
-        )
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
-        deploy_status = 'success'
-        deploy_message = 'without error'
-
         self._setup_clients(parsed_args)
 
         # Swiftclient logs things like 404s at error level, which is a problem
@@ -1059,11 +917,6 @@ class DeployOvercloud(command.Command):
 
         stack = utils.get_stack(self.orchestration_client, parsed_args.stack)
 
-        if stack and stack.stack_status == 'IN_PROGRESS':
-            raise exceptions.StackInProgress(
-                "Unable to deploy as the stack '{}' status is '{}'".format(
-                    stack.stack_name, stack.stack_status))
-
         self._update_parameters(parsed_args, stack)
 
         stack_create = stack is None
@@ -1091,35 +944,19 @@ class DeployOvercloud(command.Command):
             # wont do anything.
             return
 
-        try:
-            # Force fetching of attributes
-            stack.get()
-
-            overcloudrcs = deployment.create_overcloudrc(
-                self.clients, container=stack.stack_name,
-                no_proxy=parsed_args.no_proxy)
-            rcpath = utils.write_overcloudrc(stack.stack_name, overcloudrcs)
-
-            overcloud_endpoint = utils.get_overcloud_endpoint(stack)
-
-            horizon_url = deployment.get_horizon_url(
-                self.clients, stack=stack.stack_name)
-
-            if parsed_args.config_download:
-                print("Deploying overcloud configuration")
-                deployment.set_deployment_status(
-                    self.clients, 'deploying',
-                    plan=stack.stack_name)
+        if parsed_args.config_download:
+            print("Deploying overcloud configuration")
+            deployment.set_deployment_status(
+                self.clients, 'deploying',
+                plan=stack.stack_name)
 
+            try:
                 if not parsed_args.config_download_only:
                     deployment.get_hosts_and_enable_ssh_admin(
                         self.log, self.clients, stack,
                         parsed_args.overcloud_ssh_network,
                         parsed_args.overcloud_ssh_user,
-                        self.get_key_pair(parsed_args),
-                        parsed_args.overcloud_ssh_enable_timeout,
-                        parsed_args.overcloud_ssh_port_timeout
-                    )
+                        parsed_args.overcloud_ssh_key)
 
                 if parsed_args.config_download_timeout:
                     timeout = parsed_args.config_download_timeout * 60
@@ -1139,44 +976,53 @@ class DeployOvercloud(command.Command):
                     parsed_args.overcloud_ssh_network,
                     parsed_args.output_dir,
                     parsed_args.override_ansible_cfg,
-                    timeout=parsed_args.overcloud_ssh_port_timeout,
+                    timeout,
                     verbosity=self.app_args.verbose_level,
                     deployment_options=deployment_options,
-                    in_flight_validations=parsed_args.inflight,
-                    deployment_timeout=timeout,
-                    tags=parsed_args.tags,
-                    skip_tags=parsed_args.skip_tags,
-                    limit_hosts=utils.playbook_limit_parse(
-                        limit_nodes=parsed_args.limit
-                    ),
-                    forks=parsed_args.ansible_forks
-                )
-        except Exception as deploy_e:
-            deploy_status = 'failed'
-            deploy_message = 'with error'
-            deploy_trace = deploy_e
-            deployment.set_deployment_status(
-                self.clients, deploy_status,
-                plan=stack.stack_name)
-        finally:
-            # Copy clouds.yaml to the cloud user directory
-            user = getpwuid(os.stat(constants.CLOUD_HOME_DIR).st_uid).pw_name
-            utils.copy_clouds_yaml(user)
-            utils.create_tempest_deployer_input()
+                    in_flight_validations=parsed_args.inflight)
+            except Exception:
+                deployment.set_deployment_status(
+                    self.clients, 'failed',
+                    plan=stack.stack_name)
+                raise
 
-            # Run postconfig on create or force. Use force to makes sure
-            # endpoints are created with deploy reruns and upgrades
-            if (stack_create or parsed_args.force_postconfig
-                    and not parsed_args.skip_postconfig):
-                self._deploy_postconfig(stack, parsed_args)
+        # Force fetching of attributes
+        stack.get()
 
-            print("Overcloud Endpoint: {0}".format(overcloud_endpoint))
-            print("Overcloud Horizon Dashboard URL: {0}".format(horizon_url))
-            print("Overcloud rc file: {0}".format(rcpath))
-            print("Overcloud Deployed {0}".format(deploy_message))
+        overcloudrcs = deployment.create_overcloudrc(
+            self.clients, container=stack.stack_name,
+            no_proxy=parsed_args.no_proxy)
 
-            if deploy_status == 'failed':
-                raise(deploy_trace)
+        # Create overcloud clouds.yaml
+        cloud_data = deployment.create_cloudsyaml(
+            self.clients, container=stack.stack_name)
+        cloud_yaml_dir = os.path.join(constants.CLOUD_HOME_DIR,
+                                      constants.CLOUDS_YAML_DIR)
+        cloud_user_id = os.stat(constants.CLOUD_HOME_DIR).st_uid
+        cloud_group_id = os.stat(constants.CLOUD_HOME_DIR).st_gid
+        clouds_yaml.create_clouds_yaml(
+            cloud=cloud_data,
+            cloud_yaml_dir=cloud_yaml_dir,
+            user_id=cloud_user_id,
+            group_id=cloud_group_id)
+        rcpath = utils.write_overcloudrc(stack.stack_name, overcloudrcs)
+        utils.create_tempest_deployer_input()
+
+        # Run postconfig on create or force. Use force to makes sure endpoints
+        # are created with deploy reruns and upgrades
+        if (stack_create or parsed_args.force_postconfig
+                and not parsed_args.skip_postconfig):
+            self._deploy_postconfig(stack, parsed_args)
+
+        overcloud_endpoint = utils.get_overcloud_endpoint(stack)
+
+        horizon_url = deployment.get_horizon_url(
+            self.clients, stack=stack.stack_name)
+
+        print("Overcloud Endpoint: {0}".format(overcloud_endpoint))
+        print("Overcloud Horizon Dashboard URL: {0}".format(horizon_url))
+        print("Overcloud rc file: {0}".format(rcpath))
+        print("Overcloud Deployed")
 
 
 class GetDeploymentStatus(command.Command):
