@@ -23,7 +23,6 @@ from cliff.formatters import table
 from osc_lib import exceptions as oscexc
 from osc_lib.i18n import _
 from osc_lib import utils
-import six
 import yaml
 
 from tripleoclient import command
@@ -41,16 +40,8 @@ class DeleteNode(command.Command):
 
     def get_parser(self, prog_name):
         parser = super(DeleteNode, self).get_parser(prog_name)
-        group = parser.add_mutually_exclusive_group(required=True)
-        group.add_argument('nodes', metavar='<node>', nargs="*",
-                           default=[],
-                           help=_('Node ID(s) to delete (otherwise specified '
-                                  'in the --baremetal-deployment file)'))
-        group.add_argument('-b', '--baremetal-deployment',
-                           metavar='<BAREMETAL DEPLOYMENT FILE>',
-                           help=_('Configuration file describing the '
-                                  'baremetal deployment'))
-
+        parser.add_argument('nodes', metavar='<node>', nargs="+",
+                            help=_('Node ID(s) to delete'))
         parser.add_argument('--stack', dest='stack',
                             help=_('Name or ID of heat stack to scale '
                                    '(default=Env: OVERCLOUD_STACK_NAME)'),
@@ -88,106 +79,10 @@ class DeleteNode(command.Command):
                             action="store_true")
         return parser
 
-    def _nodes_to_delete(self, parsed_args, roles):
-        # expand for provisioned:False to get a list of nodes
-        # to delete
-        expanded = baremetal.expand_roles(
-            self.app.client_manager,
-            roles=roles,
-            stackname=parsed_args.stack,
-            provisioned=False)
-        nodes = expanded.get('instances', [])
-        if not nodes:
-            print('No nodes to unprovision')
-            return
-        TableArgs = collections.namedtuple(
-            'TableArgs', 'print_empty max_width fit_width')
-        args = TableArgs(print_empty=True, max_width=80, fit_width=True)
-        nodes_data = [(i.get('hostname', ''),
-                       i.get('name', '')) for i in nodes]
-
-        formatter = table.TableFormatter()
-        output = six.StringIO()
-        formatter.emit_list(
-            column_names=['hostname', 'name'],
-            data=nodes_data,
-            stdout=output,
-            parsed_args=args
-        )
-        return output.getvalue()
-
-    def _translate_nodes_to_resources(self, parsed_args, roles):
-        # build a dict of resource type names to role name
-        role_types = dict(
-            ('OS::TripleO::%sServer' % r['name'], r['name'])
-            for r in roles
-        )
-        expanded = baremetal.expand_roles(
-            self.app.client_manager,
-            roles=roles,
-            stackname=parsed_args.stack,
-            provisioned=True)
-
-        parameters = expanded.get(
-            'environment', {}).get('parameter_defaults', {})
-
-        # build a dict with the role and
-        # a list of indexes of nodes to delete for that role
-        removal_indexes = {}
-        for role in role_types.values():
-            removal_indexes.setdefault(role, [])
-            param = '%sRemovalPolicies' % role
-            policies = parameters.get(param, [])
-            if policies:
-                removal_indexes[role] = policies[0].get('resource_list', [])
-
-        nodes = []
-        clients = self.app.client_manager
-
-        # iterate every server resource and compare its index with
-        # the list of indexes to be deleted
-        resources = clients.orchestration.resources.list(
-            parsed_args.stack, nested_depth=5)
-        for res in resources:
-            if res.resource_type not in role_types:
-                continue
-            role = role_types[res.resource_type]
-            removal_list = removal_indexes.get(role, [])
-
-            index = int(res.parent_resource)
-            if index in removal_list:
-                node = res.physical_resource_id
-                nodes.append(node)
-        return nodes
-
-    def _check_skiplist_exists(self, env):
-        skiplist = env.get('parameter_defaults',
-                           {}).get('DeploymentServerBlacklist')
-        if skiplist:
-            self.log.warning(_('[WARNING] DeploymentServerBlacklist is '
-                               'ignored when executing scale down actions. If '
-                               'the node(s) being removed should *NOT* have '
-                               'any actions executed on them, please shut '
-                               'them off prior to their removal.'))
-
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
         clients = self.app.client_manager
 
-        if parsed_args.baremetal_deployment:
-            with open(parsed_args.baremetal_deployment, 'r') as fp:
-                roles = yaml.safe_load(fp)
-
-            nodes_text = self._nodes_to_delete(parsed_args, roles)
-            if nodes_text:
-                nodes = self._translate_nodes_to_resources(
-                    parsed_args, roles)
-                print(nodes_text)
-            else:
-                return
-        else:
-            nodes = parsed_args.nodes
-            nodes_text = '\n'.join('- %s' % node for node in nodes)
         if not parsed_args.yes:
             confirm = oooutils.prompt_user_for_confirmation(
                 message=_("Are you sure you want to delete these overcloud "
@@ -204,24 +99,17 @@ class DeleteNode(command.Command):
             raise InvalidConfiguration("stack {} not found".format(
                 parsed_args.stack))
 
+        nodes = '\n'.join('- %s' % node for node in parsed_args.nodes)
         print("Deleting the following nodes from stack {stack}:\n{nodes}"
-              .format(stack=stack.stack_name, nodes=nodes_text))
-
-        self._check_skiplist_exists(stack.environment())
+              .format(stack=stack.stack_name, nodes=nodes))
 
         scale.scale_down(
             clients,
             stack.stack_name,
-            nodes,
+            parsed_args.nodes,
             parsed_args.timeout
         )
 
-        if parsed_args.baremetal_deployment:
-            baremetal.undeploy_roles(
-                self.app.client_manager,
-                roles=roles,
-                plan=parsed_args.stack)
-
 
 class ProvideNode(command.Command):
     """Mark nodes as available based on UUIDs or current 'manageable' state."""
@@ -628,18 +516,10 @@ class ProvisionNode(command.Command):
                             help=_('User for SSH access to newly deployed '
                                    'nodes'))
         parser.add_argument('--overcloud-ssh-key',
-                            default=None,
-                            help=_('Key path for ssh access to'
-                                   'overcloud nodes. When undefined the key'
-                                   'will be autodetected.'))
-        parser.add_argument('--concurrency', type=int,
-                            default=20,
-                            help=_('Maximum number of nodes to provision at '
-                                   'once. (default=20)'))
-        parser.add_argument('--timeout', type=int,
-                            default=3600,
-                            help=_('Number of seconds to wait for the node '
-                                   'provision to complete. (default=3600)'))
+                            default=os.path.join(
+                                os.path.expanduser('~'), '.ssh', 'id_rsa.pub'),
+                            help=_('Public key path for SSH access to newly '
+                                   'deployed nodes'))
         return parser
 
     def take_action(self, parsed_args):
@@ -648,19 +528,14 @@ class ProvisionNode(command.Command):
         with open(parsed_args.input, 'r') as fp:
             roles = yaml.safe_load(fp)
 
-        key = self.get_key_pair(parsed_args)
-        with open('{}.pub'.format(key), 'rt') as fp:
+        with open(parsed_args.overcloud_ssh_key, 'rt') as fp:
             ssh_key = fp.read()
 
         output = baremetal.deploy_roles(
             self.app.client_manager,
             plan=parsed_args.stack,
-            roles=roles,
-            ssh_keys=[ssh_key],
-            ssh_user_name=parsed_args.overcloud_ssh_user,
-            concurrency=parsed_args.concurrency,
-            timeout=parsed_args.timeout
-        )
+            roles=roles, ssh_keys=[ssh_key],
+            ssh_user_name=parsed_args.overcloud_ssh_user)
 
         with open(parsed_args.output, 'w') as fp:
             yaml.safe_dump(output['environment'], fp, default_flow_style=False)
